##  Surveys
Event | Description
---|---
POLL_RESULT_CREATED | A survey response is created.
POLL_RESULT_UPDATED | A survey response is updated.
POLL_RESULT_FINALIZED (within POLL_RESULT_UPDATED) | A survey response for a fact sheet is submitted.


